# Environments

This subfolder contains `.yml` files derived from Github-Actions Workflows.

- `packages.tsv`: This file is used as input for tcy to create an input `.yml` file for Ubuntu and Windows. You can create your own repository using the tcy-repo as a template and create your
own `packages.tsv` file with the packages you need.

The subfolders `ubuntu-latest` and `windows-latest` each contain four files:

- `{OS}.yml` : This file is the result of `tcy.py` for this specific operational system. It serves as an input to create a conda environment.
- `{OS}_solved.yml` : This file is generated by exporting the **solved** environment to a file (see this [link](https://conda.io/projects/conda/en/latest/user-guide/tasks/manage-environments.html#exporting-the-environment-yml-file)).
- `{OS}_solved.txt` : This file is generated by exporting the **exact package specifications** of the **solved** environment to a file (see this [link](https://conda.io/projects/conda/en/latest/user-guide/tasks/manage-environments.html#building-identical-conda-environments)).
- `{OS}_solved_pip-requirements.txt` : This file should be used together with `{OS}_solved.txt` to also install the exact pip-packages into your environment. In the future, pip-packages should however be directly included in `{OS}_solved.txt` (see this [issue](https://github.com/conda/conda/issues/8372))
